#!/usr/bin/env python
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""This example shows use of the validate_only header when creating an ad.

Here we use a responsive search ad, but this approach can be used for any ad
type. No objects will be created in the given customer account, but exceptions
will still be thrown.
"""


import argparse
import sys
from typing import List

from google.ads.googleads.client import GoogleAdsClient
from google.ads.googleads.errors import GoogleAdsException
from google.ads.googleads.v22.services.types.ad_group_ad_service import (
    AdGroupAdOperation,
    MutateAdGroupAdsRequest,
)
from google.ads.googleads.v22.resources.types.ad_group_ad import AdGroupAd
from google.ads.googleads.v22.services.services.ad_group_service import (
    AdGroupServiceClient,
)
from google.ads.googleads.v22.common.types.ad_type_infos import AdTextAsset
from google.ads.googleads.v22.services.services.ad_group_ad_service import (
    AdGroupAdServiceClient,
)
from google.ads.googleads.v22.errors.types.policy_finding_error import (
    PolicyFindingErrorEnum,
)
from google.ads.googleads.v22.common.types.policy import PolicyTopicEntry


def main(client: GoogleAdsClient, customer_id: str, ad_group_id: str) -> None:
    ad_group_ad_operation: AdGroupAdOperation = client.get_type(
        "AdGroupAdOperation"
    )
    ad_group_ad: AdGroupAd = ad_group_ad_operation.create
    ad_group_service: AdGroupServiceClient = client.get_service(
        "AdGroupService"
    )
    ad_group_ad.ad_group = ad_group_service.ad_group_path(
        customer_id, ad_group_id
    )
    ad_group_ad.status = client.enums.AdGroupAdStatusEnum.PAUSED
    ad_group_ad.ad.final_urls.append("http://www.example.com/")

    # Create a responsive search ad.
    headline_1: AdTextAsset = client.get_type("AdTextAsset")
    headline_1.text = "Visit the Red Planet in style."
    headline_1.pinned_field = client.enums.ServedAssetFieldTypeEnum.HEADLINE_1
    ad_group_ad.ad.responsive_search_ad.headlines.append(headline_1)

    headline_2: AdTextAsset = client.get_type("AdTextAsset")
    headline_2.text = "An interplanetary adventure"
    ad_group_ad.ad.responsive_search_ad.headlines.append(headline_2)

    # Adds a headline that will trigger a policy violation to demonstrate
    # error handling.
    headline_3: AdTextAsset = client.get_type("AdTextAsset")
    headline_3.text = "Low-gravity fun for everyone!!"
    ad_group_ad.ad.responsive_search_ad.headlines.append(headline_3)

    description_1: AdTextAsset = client.get_type("AdTextAsset")
    description_1.text = "Luxury Cruise to Mars"
    ad_group_ad.ad.responsive_search_ad.descriptions.append(description_1)

    description_2: AdTextAsset = client.get_type("AdTextAsset")
    description_2.text = "Book your ticket now"
    ad_group_ad.ad.responsive_search_ad.descriptions.append(description_2)

    ad_group_ad_service: AdGroupAdServiceClient = client.get_service(
        "AdGroupAdService"
    )
    # Attempt the mutate with validate_only=True.
    try:
        request: MutateAdGroupAdsRequest = client.get_type(
            "MutateAdGroupAdsRequest"
        )
        request.customer_id = customer_id
        request.operations.append(ad_group_ad_operation)
        request.partial_failure = False
        request.validate_only = True
        # This request will trigger a POLICY_FINDING error, which is handled
        # in the below except block.
        ad_group_ad_service.mutate_ad_group_ads(request=request)
    except GoogleAdsException as ex:
        print(
            f'Request with ID "{ex.request_id}" failed with status '
            f'"{ex.error.code().name}".'
        )
        print(
            "There may have been validation error(s) while adding responsive "
            "search ad."
        )
        policy_error_enum: PolicyFindingErrorEnum.PolicyFindingError = (
            client.get_type(
                "PolicyFindingErrorEnum"
            ).PolicyFindingError.POLICY_FINDING
        )

        count: int = 1
        for err in ex.failure.errors:
            # err: GoogleAdsError = err <- Removed type hint
            # Note: Policy violation errors are returned as PolicyFindingErrors.
            # For additional details, see
            # https://developers.google.com/google-ads/api/docs/policy-exemption/overview
            if err.error_code.policy_finding_error == policy_error_enum:
                if err.details.policy_finding_details:
                    details: List[PolicyTopicEntry] = (
                        err.details.policy_finding_details.policy_topic_entries
                    )
                    for pol_entry in details:
                        # pol_entry: PolicyTopicEntry = pol_entry <- Removed type hint
                        print(f"{count}) Policy topic entry: \n{pol_entry}\n")
                count += 1
            else:
                print(
                    f"\tNon-policy finding error with message "
                    f'"{err.message}".'
                )
                if err.location:
                    for field_path_element in err.location.field_path_elements:
                        print(f"\t\tOn field: {field_path_element.field_name}")
                sys.exit(1)


if __name__ == "__main__":
    parser: argparse.ArgumentParser = argparse.ArgumentParser(
        description=(
            "Shows how to use the validate_only header to validate a "
            "responsive search ad. No objects will be created, but exceptions "
            "will still be thrown."
        )
    )

    # The following argument(s) should be provided to run the example.
    parser.add_argument(
        "-c",
        "--customer_id",
        type=str,
        required=True,
        help="The Google Ads customer ID.",
    )
    parser.add_argument(
        "-a", "--ad_group_id", type=str, required=True, help="The Ad Group ID."
    )
    args: argparse.Namespace = parser.parse_args()

    # GoogleAdsClient will read the google-ads.yaml configuration file in the
    # home directory if none is specified.
    googleads_client: GoogleAdsClient = GoogleAdsClient.load_from_storage(
        version="v22"
    )

    main(googleads_client, args.customer_id, args.ad_group_id)



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableSequence

import proto  # type: ignore

from google.ads.googleads.v19.enums.types import age_range_type
from google.ads.googleads.v19.enums.types import app_payment_model_type
from google.ads.googleads.v19.enums.types import brand_request_rejection_reason
from google.ads.googleads.v19.enums.types import brand_state
from google.ads.googleads.v19.enums.types import content_label_type
from google.ads.googleads.v19.enums.types import day_of_week as gage_day_of_week
from google.ads.googleads.v19.enums.types import device
from google.ads.googleads.v19.enums.types import gender_type
from google.ads.googleads.v19.enums.types import hotel_date_selection_type
from google.ads.googleads.v19.enums.types import income_range_type
from google.ads.googleads.v19.enums.types import interaction_type
from google.ads.googleads.v19.enums.types import keyword_match_type
from google.ads.googleads.v19.enums.types import listing_group_type
from google.ads.googleads.v19.enums.types import location_group_radius_units
from google.ads.googleads.v19.enums.types import minute_of_hour
from google.ads.googleads.v19.enums.types import parental_status_type
from google.ads.googleads.v19.enums.types import product_category_level
from google.ads.googleads.v19.enums.types import (
    product_channel as gage_product_channel,
)
from google.ads.googleads.v19.enums.types import (
    product_channel_exclusivity as gage_product_channel_exclusivity,
)
from google.ads.googleads.v19.enums.types import (
    product_condition as gage_product_condition,
)
from google.ads.googleads.v19.enums.types import product_custom_attribute_index
from google.ads.googleads.v19.enums.types import product_type_level
from google.ads.googleads.v19.enums.types import proximity_radius_units
from google.ads.googleads.v19.enums.types import webpage_condition_operand
from google.ads.googleads.v19.enums.types import webpage_condition_operator


__protobuf__ = proto.module(
    package="google.ads.googleads.v19.common",
    marshal="google.ads.googleads.v19",
    manifest={
        "KeywordInfo",
        "PlacementInfo",
        "NegativeKeywordListInfo",
        "MobileAppCategoryInfo",
        "MobileApplicationInfo",
        "LocationInfo",
        "DeviceInfo",
        "ListingGroupInfo",
        "ListingDimensionPath",
        "ListingScopeInfo",
        "ListingDimensionInfo",
        "HotelIdInfo",
        "HotelClassInfo",
        "HotelCountryRegionInfo",
        "HotelStateInfo",
        "HotelCityInfo",
        "ProductCategoryInfo",
        "ProductBrandInfo",
        "ProductChannelInfo",
        "ProductChannelExclusivityInfo",
        "ProductConditionInfo",
        "ProductCustomAttributeInfo",
        "ProductItemIdInfo",
        "ProductTypeInfo",
        "ProductGroupingInfo",
        "ProductLabelsInfo",
        "ProductLegacyConditionInfo",
        "ProductTypeFullInfo",
        "UnknownListingDimensionInfo",
        "HotelDateSelectionTypeInfo",
        "HotelAdvanceBookingWindowInfo",
        "HotelLengthOfStayInfo",
        "HotelCheckInDateRangeInfo",
        "HotelCheckInDayInfo",
        "ActivityIdInfo",
        "ActivityRatingInfo",
        "ActivityCountryInfo",
        "ActivityStateInfo",
        "ActivityCityInfo",
        "InteractionTypeInfo",
        "AdScheduleInfo",
        "AgeRangeInfo",
        "GenderInfo",
        "IncomeRangeInfo",
        "ParentalStatusInfo",
        "YouTubeVideoInfo",
        "YouTubeChannelInfo",
        "UserListInfo",
        "ProximityInfo",
        "GeoPointInfo",
        "AddressInfo",
        "TopicInfo",
        "LanguageInfo",
        "IpBlockInfo",
        "ContentLabelInfo",
        "CarrierInfo",
        "UserInterestInfo",
        "WebpageInfo",
        "WebpageConditionInfo",
        "WebpageSampleInfo",
        "OperatingSystemVersionInfo",
        "AppPaymentModelInfo",
        "MobileDeviceInfo",
        "CustomAffinityInfo",
        "CustomIntentInfo",
        "LocationGroupInfo",
        "CustomAudienceInfo",
        "CombinedAudienceInfo",
        "AudienceInfo",
        "KeywordThemeInfo",
        "LocalServiceIdInfo",
        "SearchThemeInfo",
        "BrandInfo",
        "BrandListInfo",
    },
)


class KeywordInfo(proto.Message):
    r"""A keyword criterion.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        text (str):
            The text of the keyword (at most 80
            characters and 10 words).

            This field is a member of `oneof`_ ``_text``.
        match_type (google.ads.googleads.v19.enums.types.KeywordMatchTypeEnum.KeywordMatchType):
            The match type of the keyword.
    """

    text: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    match_type: keyword_match_type.KeywordMatchTypeEnum.KeywordMatchType = (
        proto.Field(
            proto.ENUM,
            number=2,
            enum=keyword_match_type.KeywordMatchTypeEnum.KeywordMatchType,
        )
    )


class PlacementInfo(proto.Message):
    r"""A placement criterion. This can be used to modify bids for
    sites when targeting the content network.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        url (str):
            URL of the placement.

            For example, "http://www.domain.com".

            This field is a member of `oneof`_ ``_url``.
    """

    url: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class NegativeKeywordListInfo(proto.Message):
    r"""A Negative Keyword List criterion. Represents a shared set
    of negative keywords that can be excluded at the account-level.
    Only one negative keyword list criterion can be attached per
    account.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        shared_set (str):
            The NegativeKeywordListInfo shared set
            resource name.

            This field is a member of `oneof`_ ``_shared_set``.
    """

    shared_set: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


class MobileAppCategoryInfo(proto.Message):
    r"""A mobile app category criterion.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        mobile_app_category_constant (str):
            The mobile app category constant resource
            name.

            This field is a member of `oneof`_ ``_mobile_app_category_constant``.
    """

    mobile_app_category_constant: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class MobileApplicationInfo(proto.Message):
    r"""A mobile application criterion.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        app_id (str):
            A string that uniquely identifies a mobile application to
            Google Ads API. The format of this string is
            "{platform}-{platform_native_id}", where platform is "1" for
            iOS apps and "2" for Android apps, and where
            platform_native_id is the mobile application identifier
            native to the corresponding platform. For iOS, this native
            identifier is the 9 digit string that appears at the end of
            an App Store URL (for example, "476943146" for "Flood-It! 2"
            whose App Store link is
            "http://itunes.apple.com/us/app/flood-it!-2/id476943146").
            For Android, this native identifier is the application's
            package name (for example, "com.labpixies.colordrips" for
            "Color Drips" given Google Play link
            "https://play.google.com/store/apps/details?id=com.labpixies.colordrips").
            A well formed app id for Google Ads API would thus be
            "1-476943146" for iOS and "2-com.labpixies.colordrips" for
            Android. This field is required and must be set in CREATE
            operations.

            This field is a member of `oneof`_ ``_app_id``.
        name (str):
            Name of this mobile application.

            This field is a member of `oneof`_ ``_name``.
    """

    app_id: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    name: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )


class LocationInfo(proto.Message):
    r"""A location criterion.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        geo_target_constant (str):
            The geo target constant resource name.

            This field is a member of `oneof`_ ``_geo_target_constant``.
    """

    geo_target_constant: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class DeviceInfo(proto.Message):
    r"""A device criterion.

    Attributes:
        type_ (google.ads.googleads.v19.enums.types.DeviceEnum.Device):
            Type of the device.
    """

    type_: device.DeviceEnum.Device = proto.Field(
        proto.ENUM,
        number=1,
        enum=device.DeviceEnum.Device,
    )


class ListingGroupInfo(proto.Message):
    r"""A listing group criterion.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        type_ (google.ads.googleads.v19.enums.types.ListingGroupTypeEnum.ListingGroupType):
            Type of the listing group.
        case_value (google.ads.googleads.v19.common.types.ListingDimensionInfo):
            Dimension value with which this listing group
            is refining its parent. Undefined for the root
            group.
        parent_ad_group_criterion (str):
            Resource name of ad group criterion which is
            the parent listing group subdivision. Null for
            the root group.

            This field is a member of `oneof`_ ``_parent_ad_group_criterion``.
        path (google.ads.googleads.v19.common.types.ListingDimensionPath):
            The path of dimensions defining this listing
            group.

            This field is a member of `oneof`_ ``_path``.
    """

    type_: listing_group_type.ListingGroupTypeEnum.ListingGroupType = (
        proto.Field(
            proto.ENUM,
            number=1,
            enum=listing_group_type.ListingGroupTypeEnum.ListingGroupType,
        )
    )
    case_value: "ListingDimensionInfo" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="ListingDimensionInfo",
    )
    parent_ad_group_criterion: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    path: "ListingDimensionPath" = proto.Field(
        proto.MESSAGE,
        number=5,
        optional=True,
        message="ListingDimensionPath",
    )


class ListingDimensionPath(proto.Message):
    r"""The path of dimensions defining a listing group.

    Attributes:
        dimensions (MutableSequence[google.ads.googleads.v19.common.types.ListingDimensionInfo]):
            The complete path of dimensions through the
            listing group hierarchy, from the root
            (excluding the root itself) to this listing
            group.
    """

    dimensions: MutableSequence["ListingDimensionInfo"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="ListingDimensionInfo",
    )


class ListingScopeInfo(proto.Message):
    r"""A listing scope criterion.

    Attributes:
        dimensions (MutableSequence[google.ads.googleads.v19.common.types.ListingDimensionInfo]):
            Scope of the campaign criterion.
    """

    dimensions: MutableSequence["ListingDimensionInfo"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="ListingDimensionInfo",
    )


class ListingDimensionInfo(proto.Message):
    r"""Listing dimensions for listing group criterion.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        hotel_id (google.ads.googleads.v19.common.types.HotelIdInfo):
            Advertiser-specific hotel ID.

            This field is a member of `oneof`_ ``dimension``.
        hotel_class (google.ads.googleads.v19.common.types.HotelClassInfo):
            Class of the hotel as a number of stars 1 to
            5.

            This field is a member of `oneof`_ ``dimension``.
        hotel_country_region (google.ads.googleads.v19.common.types.HotelCountryRegionInfo):
            Country or Region the hotel is located in.

            This field is a member of `oneof`_ ``dimension``.
        hotel_state (google.ads.googleads.v19.common.types.HotelStateInfo):
            State the hotel is located in.

            This field is a member of `oneof`_ ``dimension``.
        hotel_city (google.ads.googleads.v19.common.types.HotelCityInfo):
            City the hotel is located in.

            This field is a member of `oneof`_ ``dimension``.
        product_category (google.ads.googleads.v19.common.types.ProductCategoryInfo):
            Category of a product offer.

            This field is a member of `oneof`_ ``dimension``.
        product_brand (google.ads.googleads.v19.common.types.ProductBrandInfo):
            Brand of a product offer.

            This field is a member of `oneof`_ ``dimension``.
        product_channel (google.ads.googleads.v19.common.types.ProductChannelInfo):
            Locality of a product offer.

            This field is a member of `oneof`_ ``dimension``.
        product_channel_exclusivity (google.ads.googleads.v19.common.types.ProductChannelExclusivityInfo):
            Availability of a product offer.

            This field is a member of `oneof`_ ``dimension``.
        product_condition (google.ads.googleads.v19.common.types.ProductConditionInfo):
            Condition of a product offer.

            This field is a member of `oneof`_ ``dimension``.
        product_custom_attribute (google.ads.googleads.v19.common.types.ProductCustomAttributeInfo):
            Custom attribute of a product offer.

            This field is a member of `oneof`_ ``dimension``.
        product_item_id (google.ads.googleads.v19.common.types.ProductItemIdInfo):
            Item id of a product offer.

            This field is a member of `oneof`_ ``dimension``.
        product_type (google.ads.googleads.v19.common.types.ProductTypeInfo):
            Type of a product offer.

            This field is a member of `oneof`_ ``dimension``.
        product_grouping (google.ads.googleads.v19.common.types.ProductGroupingInfo):
            Grouping of a product offer. This listing
            dimension is deprecated and it is supported only
            in Display campaigns.

            This field is a member of `oneof`_ ``dimension``.
        product_labels (google.ads.googleads.v19.common.types.ProductLabelsInfo):
            Labels of a product offer. This listing
            dimension is deprecated and it is supported only
            in Display campaigns.

            This field is a member of `oneof`_ ``dimension``.
        product_legacy_condition (google.ads.googleads.v19.common.types.ProductLegacyConditionInfo):
            Legacy condition of a product offer. This
            listing dimension is deprecated and it is
            supported only in Display campaigns.

            This field is a member of `oneof`_ ``dimension``.
        product_type_full (google.ads.googleads.v19.common.types.ProductTypeFullInfo):
            Full type of a product offer. This listing
            dimension is deprecated and it is supported only
            in Display campaigns.

            This field is a member of `oneof`_ ``dimension``.
        activity_id (google.ads.googleads.v19.common.types.ActivityIdInfo):
            Advertiser-specific activity ID.

            This field is a member of `oneof`_ ``dimension``.
        activity_rating (google.ads.googleads.v19.common.types.ActivityRatingInfo):
            Rating of the activity as a number 1 to 5,
            where 5 is the best.

            This field is a member of `oneof`_ ``dimension``.
        activity_country (google.ads.googleads.v19.common.types.ActivityCountryInfo):
            The country where the travel activity is
            available.

            This field is a member of `oneof`_ ``dimension``.
        activity_state (google.ads.googleads.v19.common.types.ActivityStateInfo):
            The state where the travel activity is
            available.

            This field is a member of `oneof`_ ``dimension``.
        activity_city (google.ads.googleads.v19.common.types.ActivityCityInfo):
            The city where the travel activity is
            available.

            This field is a member of `oneof`_ ``dimension``.
        unknown_listing_dimension (google.ads.googleads.v19.common.types.UnknownListingDimensionInfo):
            Unknown dimension. Set when no other listing
            dimension is set.

            This field is a member of `oneof`_ ``dimension``.
    """

    hotel_id: "HotelIdInfo" = proto.Field(
        proto.MESSAGE,
        number=2,
        oneof="dimension",
        message="HotelIdInfo",
    )
    hotel_class: "HotelClassInfo" = proto.Field(
        proto.MESSAGE,
        number=3,
        oneof="dimension",
        message="HotelClassInfo",
    )
    hotel_country_region: "HotelCountryRegionInfo" = proto.Field(
        proto.MESSAGE,
        number=4,
        oneof="dimension",
        message="HotelCountryRegionInfo",
    )
    hotel_state: "HotelStateInfo" = proto.Field(
        proto.MESSAGE,
        number=5,
        oneof="dimension",
        message="HotelStateInfo",
    )
    hotel_city: "HotelCityInfo" = proto.Field(
        proto.MESSAGE,
        number=6,
        oneof="dimension",
        message="HotelCityInfo",
    )
    product_category: "ProductCategoryInfo" = proto.Field(
        proto.MESSAGE,
        number=24,
        oneof="dimension",
        message="ProductCategoryInfo",
    )
    product_brand: "ProductBrandInfo" = proto.Field(
        proto.MESSAGE,
        number=15,
        oneof="dimension",
        message="ProductBrandInfo",
    )
    product_channel: "ProductChannelInfo" = proto.Field(
        proto.MESSAGE,
        number=8,
        oneof="dimension",
        message="ProductChannelInfo",
    )
    product_channel_exclusivity: "ProductChannelExclusivityInfo" = proto.Field(
        proto.MESSAGE,
        number=9,
        oneof="dimension",
        message="ProductChannelExclusivityInfo",
    )
    product_condition: "ProductConditionInfo" = proto.Field(
        proto.MESSAGE,
        number=10,
        oneof="dimension",
        message="ProductConditionInfo",
    )
    product_custom_attribute: "ProductCustomAttributeInfo" = proto.Field(
        proto.MESSAGE,
        number=16,
        oneof="dimension",
        message="ProductCustomAttributeInfo",
    )
    product_item_id: "ProductItemIdInfo" = proto.Field(
        proto.MESSAGE,
        number=11,
        oneof="dimension",
        message="ProductItemIdInfo",
    )
    product_type: "ProductTypeInfo" = proto.Field(
        proto.MESSAGE,
        number=12,
        oneof="dimension",
        message="ProductTypeInfo",
    )
    product_grouping: "ProductGroupingInfo" = proto.Field(
        proto.MESSAGE,
        number=17,
        oneof="dimension",
        message="ProductGroupingInfo",
    )
    product_labels: "ProductLabelsInfo" = proto.Field(
        proto.MESSAGE,
        number=18,
        oneof="dimension",
        message="ProductLabelsInfo",
    )
    product_legacy_condition: "ProductLegacyConditionInfo" = proto.Field(
        proto.MESSAGE,
        number=19,
        oneof="dimension",
        message="ProductLegacyConditionInfo",
    )
    product_type_full: "ProductTypeFullInfo" = proto.Field(
        proto.MESSAGE,
        number=20,
        oneof="dimension",
        message="ProductTypeFullInfo",
    )
    activity_id: "ActivityIdInfo" = proto.Field(
        proto.MESSAGE,
        number=21,
        oneof="dimension",
        message="ActivityIdInfo",
    )
    activity_rating: "ActivityRatingInfo" = proto.Field(
        proto.MESSAGE,
        number=22,
        oneof="dimension",
        message="ActivityRatingInfo",
    )
    activity_country: "ActivityCountryInfo" = proto.Field(
        proto.MESSAGE,
        number=23,
        oneof="dimension",
        message="ActivityCountryInfo",
    )
    activity_state: "ActivityStateInfo" = proto.Field(
        proto.MESSAGE,
        number=25,
        oneof="dimension",
        message="ActivityStateInfo",
    )
    activity_city: "ActivityCityInfo" = proto.Field(
        proto.MESSAGE,
        number=26,
        oneof="dimension",
        message="ActivityCityInfo",
    )
    unknown_listing_dimension: "UnknownListingDimensionInfo" = proto.Field(
        proto.MESSAGE,
        number=14,
        oneof="dimension",
        message="UnknownListingDimensionInfo",
    )


class HotelIdInfo(proto.Message):
    r"""Advertiser-specific hotel ID.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (str):
            String value of the hotel ID.

            This field is a member of `oneof`_ ``_value``.
    """

    value: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class HotelClassInfo(proto.Message):
    r"""Class of the hotel as a number of stars 1 to 5.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (int):
            Long value of the hotel class.

            This field is a member of `oneof`_ ``_value``.
    """

    value: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )


class HotelCountryRegionInfo(proto.Message):
    r"""Country or Region the hotel is located in.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        country_region_criterion (str):
            The Geo Target Constant resource name.

            This field is a member of `oneof`_ ``_country_region_criterion``.
    """

    country_region_criterion: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class HotelStateInfo(proto.Message):
    r"""State the hotel is located in.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        state_criterion (str):
            The Geo Target Constant resource name.

            This field is a member of `oneof`_ ``_state_criterion``.
    """

    state_criterion: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class HotelCityInfo(proto.Message):
    r"""City the hotel is located in.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        city_criterion (str):
            The Geo Target Constant resource name.

            This field is a member of `oneof`_ ``_city_criterion``.
    """

    city_criterion: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class ProductCategoryInfo(proto.Message):
    r"""Category of a product offer.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        category_id (int):
            ID of the product category.

            This ID is equivalent to the google_product_category ID as
            described in this article:
            https://support.google.com/merchants/answer/6324436

            This field is a member of `oneof`_ ``_category_id``.
        level (google.ads.googleads.v19.enums.types.ProductCategoryLevelEnum.ProductCategoryLevel):
            Level of the product category.
    """

    category_id: int = proto.Field(
        proto.INT64,
        number=1,
        optional=True,
    )
    level: (
        product_category_level.ProductCategoryLevelEnum.ProductCategoryLevel
    ) = proto.Field(
        proto.ENUM,
        number=2,
        enum=product_category_level.ProductCategoryLevelEnum.ProductCategoryLevel,
    )


class ProductBrandInfo(proto.Message):
    r"""Brand of the product.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (str):
            String value of the product brand.

            This field is a member of `oneof`_ ``_value``.
    """

    value: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class ProductChannelInfo(proto.Message):
    r"""Locality of a product offer.

    Attributes:
        channel (google.ads.googleads.v19.enums.types.ProductChannelEnum.ProductChannel):
            Value of the locality.
    """

    channel: gage_product_channel.ProductChannelEnum.ProductChannel = (
        proto.Field(
            proto.ENUM,
            number=1,
            enum=gage_product_channel.ProductChannelEnum.ProductChannel,
        )
    )


class ProductChannelExclusivityInfo(proto.Message):
    r"""Availability of a product offer.

    Attributes:
        channel_exclusivity (google.ads.googleads.v19.enums.types.ProductChannelExclusivityEnum.ProductChannelExclusivity):
            Value of the availability.
    """

    channel_exclusivity: (
        gage_product_channel_exclusivity.ProductChannelExclusivityEnum.ProductChannelExclusivity
    ) = proto.Field(
        proto.ENUM,
        number=1,
        enum=gage_product_channel_exclusivity.ProductChannelExclusivityEnum.ProductChannelExclusivity,
    )


class ProductConditionInfo(proto.Message):
    r"""Condition of a product offer.

    Attributes:
        condition (google.ads.googleads.v19.enums.types.ProductConditionEnum.ProductCondition):
            Value of the condition.
    """

    condition: gage_product_condition.ProductConditionEnum.ProductCondition = (
        proto.Field(
            proto.ENUM,
            number=1,
            enum=gage_product_condition.ProductConditionEnum.ProductCondition,
        )
    )


class ProductCustomAttributeInfo(proto.Message):
    r"""Custom attribute of a product offer.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (str):
            String value of the product custom attribute.

            This field is a member of `oneof`_ ``_value``.
        index (google.ads.googleads.v19.enums.types.ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex):
            Indicates the index of the custom attribute.
    """

    value: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    index: (
        product_custom_attribute_index.ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex
    ) = proto.Field(
        proto.ENUM,
        number=2,
        enum=product_custom_attribute_index.ProductCustomAttributeIndexEnum.ProductCustomAttributeIndex,
    )


class ProductItemIdInfo(proto.Message):
    r"""Item id of a product offer.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (str):
            Value of the id.

            This field is a member of `oneof`_ ``_value``.
    """

    value: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class ProductTypeInfo(proto.Message):
    r"""Type of a product offer.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (str):
            Value of the type.

            This field is a member of `oneof`_ ``_value``.
        level (google.ads.googleads.v19.enums.types.ProductTypeLevelEnum.ProductTypeLevel):
            Level of the type.
    """

    value: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    level: product_type_level.ProductTypeLevelEnum.ProductTypeLevel = (
        proto.Field(
            proto.ENUM,
            number=2,
            enum=product_type_level.ProductTypeLevelEnum.ProductTypeLevel,
        )
    )


class ProductGroupingInfo(proto.Message):
    r"""Grouping of a product offer. This listing dimension is
    deprecated and it is supported only in Display campaigns.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (str):
            String value of the product grouping.

            This field is a member of `oneof`_ ``_value``.
    """

    value: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


class ProductLabelsInfo(proto.Message):
    r"""Labels of a product offer. This listing dimension is
    deprecated and it is supported only in Display campaigns.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (str):
            String value of the product labels.

            This field is a member of `oneof`_ ``_value``.
    """

    value: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


class ProductLegacyConditionInfo(proto.Message):
    r"""Legacy condition of a product offer. This listing dimension
    is deprecated and it is supported only in Display campaigns.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (str):
            String value of the product legacy condition.

            This field is a member of `oneof`_ ``_value``.
    """

    value: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


class ProductTypeFullInfo(proto.Message):
    r"""Full type of a product offer. This listing dimension is
    deprecated and it is supported only in Display campaigns.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (str):
            String value of the product full type.

            This field is a member of `oneof`_ ``_value``.
    """

    value: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


class UnknownListingDimensionInfo(proto.Message):
    r"""Unknown listing dimension."""


class HotelDateSelectionTypeInfo(proto.Message):
    r"""Criterion for hotel date selection (default dates versus user
    selected).

    Attributes:
        type_ (google.ads.googleads.v19.enums.types.HotelDateSelectionTypeEnum.HotelDateSelectionType):
            Type of the hotel date selection
    """

    type_: (
        hotel_date_selection_type.HotelDateSelectionTypeEnum.HotelDateSelectionType
    ) = proto.Field(
        proto.ENUM,
        number=1,
        enum=hotel_date_selection_type.HotelDateSelectionTypeEnum.HotelDateSelectionType,
    )


class HotelAdvanceBookingWindowInfo(proto.Message):
    r"""Criterion for number of days prior to the stay the booking is
    being made.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        min_days (int):
            Low end of the number of days prior to the
            stay.

            This field is a member of `oneof`_ ``_min_days``.
        max_days (int):
            High end of the number of days prior to the
            stay.

            This field is a member of `oneof`_ ``_max_days``.
    """

    min_days: int = proto.Field(
        proto.INT64,
        number=3,
        optional=True,
    )
    max_days: int = proto.Field(
        proto.INT64,
        number=4,
        optional=True,
    )


class HotelLengthOfStayInfo(proto.Message):
    r"""Criterion for length of hotel stay in nights.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        min_nights (int):
            Low end of the number of nights in the stay.

            This field is a member of `oneof`_ ``_min_nights``.
        max_nights (int):
            High end of the number of nights in the stay.

            This field is a member of `oneof`_ ``_max_nights``.
    """

    min_nights: int = proto.Field(
        proto.INT64,
        number=3,
        optional=True,
    )
    max_nights: int = proto.Field(
        proto.INT64,
        number=4,
        optional=True,
    )


class HotelCheckInDateRangeInfo(proto.Message):
    r"""Criterion for a check-in date range.

    Attributes:
        start_date (str):
            Start date in the YYYY-MM-DD format.
        end_date (str):
            End date in the YYYY-MM-DD format.
    """

    start_date: str = proto.Field(
        proto.STRING,
        number=1,
    )
    end_date: str = proto.Field(
        proto.STRING,
        number=2,
    )


class HotelCheckInDayInfo(proto.Message):
    r"""Criterion for day of the week the booking is for.

    Attributes:
        day_of_week (google.ads.googleads.v19.enums.types.DayOfWeekEnum.DayOfWeek):
            The day of the week.
    """

    day_of_week: gage_day_of_week.DayOfWeekEnum.DayOfWeek = proto.Field(
        proto.ENUM,
        number=1,
        enum=gage_day_of_week.DayOfWeekEnum.DayOfWeek,
    )


class ActivityIdInfo(proto.Message):
    r"""Advertiser-specific activity ID.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (str):
            String value of the activity ID.

            This field is a member of `oneof`_ ``_value``.
    """

    value: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


class ActivityRatingInfo(proto.Message):
    r"""Rating of the activity as a number 1 to 5, where 5 is the
    best.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (int):
            Long value of the activity rating.

            This field is a member of `oneof`_ ``_value``.
    """

    value: int = proto.Field(
        proto.INT64,
        number=1,
        optional=True,
    )


class ActivityCountryInfo(proto.Message):
    r"""The country where the travel activity is available.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (str):
            String value of the activity country. The Geo
            Target Constant resource name.

            This field is a member of `oneof`_ ``_value``.
    """

    value: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


class ActivityStateInfo(proto.Message):
    r"""The state where the travel activity is available.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (str):
            String value of the activity state. The Geo
            Target Constant resource name.

            This field is a member of `oneof`_ ``_value``.
    """

    value: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


class ActivityCityInfo(proto.Message):
    r"""The city where the travel activity is available.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        value (str):
            String value of the activity city. The Geo
            Target Constant resource name.

            This field is a member of `oneof`_ ``_value``.
    """

    value: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


class InteractionTypeInfo(proto.Message):
    r"""Criterion for Interaction Type.

    Attributes:
        type_ (google.ads.googleads.v19.enums.types.InteractionTypeEnum.InteractionType):
            The interaction type.
    """

    type_: interaction_type.InteractionTypeEnum.InteractionType = proto.Field(
        proto.ENUM,
        number=1,
        enum=interaction_type.InteractionTypeEnum.InteractionType,
    )


class AdScheduleInfo(proto.Message):
    r"""Represents an AdSchedule criterion.

    AdSchedule is specified as the day of the week and a time
    interval within which ads will be shown.

    No more than six AdSchedules can be added for the same day.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        start_minute (google.ads.googleads.v19.enums.types.MinuteOfHourEnum.MinuteOfHour):
            Minutes after the start hour at which this
            schedule starts.
            This field is required for CREATE operations and
            is prohibited on UPDATE operations.
        end_minute (google.ads.googleads.v19.enums.types.MinuteOfHourEnum.MinuteOfHour):
            Minutes after the end hour at which this
            schedule ends. The schedule is exclusive of the
            end minute.

            This field is required for CREATE operations and
            is prohibited on UPDATE operations.
        start_hour (int):
            Starting hour in 24 hour time.
            This field must be between 0 and 23, inclusive.

            This field is required for CREATE operations and
            is prohibited on UPDATE operations.

            This field is a member of `oneof`_ ``_start_hour``.
        end_hour (int):
            Ending hour in 24 hour time; 24 signifies end
            of the day. This field must be between 0 and 24,
            inclusive.

            This field is required for CREATE operations and
            is prohibited on UPDATE operations.

            This field is a member of `oneof`_ ``_end_hour``.
        day_of_week (google.ads.googleads.v19.enums.types.DayOfWeekEnum.DayOfWeek):
            Day of the week the schedule applies to.

            This field is required for CREATE operations and
            is prohibited on UPDATE operations.
    """

    start_minute: minute_of_hour.MinuteOfHourEnum.MinuteOfHour = proto.Field(
        proto.ENUM,
        number=1,
        enum=minute_of_hour.MinuteOfHourEnum.MinuteOfHour,
    )
    end_minute: minute_of_hour.MinuteOfHourEnum.MinuteOfHour = proto.Field(
        proto.ENUM,
        number=2,
        enum=minute_of_hour.MinuteOfHourEnum.MinuteOfHour,
    )
    start_hour: int = proto.Field(
        proto.INT32,
        number=6,
        optional=True,
    )
    end_hour: int = proto.Field(
        proto.INT32,
        number=7,
        optional=True,
    )
    day_of_week: gage_day_of_week.DayOfWeekEnum.DayOfWeek = proto.Field(
        proto.ENUM,
        number=5,
        enum=gage_day_of_week.DayOfWeekEnum.DayOfWeek,
    )


class AgeRangeInfo(proto.Message):
    r"""An age range criterion.

    Attributes:
        type_ (google.ads.googleads.v19.enums.types.AgeRangeTypeEnum.AgeRangeType):
            Type of the age range.
    """

    type_: age_range_type.AgeRangeTypeEnum.AgeRangeType = proto.Field(
        proto.ENUM,
        number=1,
        enum=age_range_type.AgeRangeTypeEnum.AgeRangeType,
    )


class GenderInfo(proto.Message):
    r"""A gender criterion.

    Attributes:
        type_ (google.ads.googleads.v19.enums.types.GenderTypeEnum.GenderType):
            Type of the gender.
    """

    type_: gender_type.GenderTypeEnum.GenderType = proto.Field(
        proto.ENUM,
        number=1,
        enum=gender_type.GenderTypeEnum.GenderType,
    )


class IncomeRangeInfo(proto.Message):
    r"""An income range criterion.

    Attributes:
        type_ (google.ads.googleads.v19.enums.types.IncomeRangeTypeEnum.IncomeRangeType):
            Type of the income range.
    """

    type_: income_range_type.IncomeRangeTypeEnum.IncomeRangeType = proto.Field(
        proto.ENUM,
        number=1,
        enum=income_range_type.IncomeRangeTypeEnum.IncomeRangeType,
    )


class ParentalStatusInfo(proto.Message):
    r"""A parental status criterion.

    Attributes:
        type_ (google.ads.googleads.v19.enums.types.ParentalStatusTypeEnum.ParentalStatusType):
            Type of the parental status.
    """

    type_: parental_status_type.ParentalStatusTypeEnum.ParentalStatusType = (
        proto.Field(
            proto.ENUM,
            number=1,
            enum=parental_status_type.ParentalStatusTypeEnum.ParentalStatusType,
        )
    )


class YouTubeVideoInfo(proto.Message):
    r"""A YouTube Video criterion.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        video_id (str):
            YouTube video id as it appears on the YouTube
            watch page.

            This field is a member of `oneof`_ ``_video_id``.
    """

    video_id: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class YouTubeChannelInfo(proto.Message):
    r"""A YouTube Channel criterion.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        channel_id (str):
            The YouTube uploader channel id or the
            channel code of a YouTube channel.

            This field is a member of `oneof`_ ``_channel_id``.
    """

    channel_id: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class UserListInfo(proto.Message):
    r"""A User List criterion. Represents a user list that is defined
    by the advertiser to be targeted.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        user_list (str):
            The User List resource name.

            This field is a member of `oneof`_ ``_user_list``.
    """

    user_list: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class ProximityInfo(proto.Message):
    r"""A Proximity criterion. The geo point and radius determine
    what geographical area is included. The address is a description
    of the geo point that does not affect ad serving.

    There are two ways to create a proximity. First, by setting an
    address and radius. The geo point will be automatically
    computed. Second, by setting a geo point and radius. The address
    is an optional label that won't be validated.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        geo_point (google.ads.googleads.v19.common.types.GeoPointInfo):
            Latitude and longitude.
        radius (float):
            The radius of the proximity.

            This field is a member of `oneof`_ ``_radius``.
        radius_units (google.ads.googleads.v19.enums.types.ProximityRadiusUnitsEnum.ProximityRadiusUnits):
            The unit of measurement of the radius.
            Default is KILOMETERS.
        address (google.ads.googleads.v19.common.types.AddressInfo):
            Full address.
    """

    geo_point: "GeoPointInfo" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="GeoPointInfo",
    )
    radius: float = proto.Field(
        proto.DOUBLE,
        number=5,
        optional=True,
    )
    radius_units: (
        proximity_radius_units.ProximityRadiusUnitsEnum.ProximityRadiusUnits
    ) = proto.Field(
        proto.ENUM,
        number=3,
        enum=proximity_radius_units.ProximityRadiusUnitsEnum.ProximityRadiusUnits,
    )
    address: "AddressInfo" = proto.Field(
        proto.MESSAGE,
        number=4,
        message="AddressInfo",
    )


class GeoPointInfo(proto.Message):
    r"""Geo point for proximity criterion.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        longitude_in_micro_degrees (int):
            Micro degrees for the longitude.

            This field is a member of `oneof`_ ``_longitude_in_micro_degrees``.
        latitude_in_micro_degrees (int):
            Micro degrees for the latitude.

            This field is a member of `oneof`_ ``_latitude_in_micro_degrees``.
    """

    longitude_in_micro_degrees: int = proto.Field(
        proto.INT32,
        number=3,
        optional=True,
    )
    latitude_in_micro_degrees: int = proto.Field(
        proto.INT32,
        number=4,
        optional=True,
    )


class AddressInfo(proto.Message):
    r"""Address for proximity criterion.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        postal_code (str):
            Postal code.

            This field is a member of `oneof`_ ``_postal_code``.
        province_code (str):
            Province or state code.

            This field is a member of `oneof`_ ``_province_code``.
        country_code (str):
            Country code.

            This field is a member of `oneof`_ ``_country_code``.
        province_name (str):
            Province or state name.

            This field is a member of `oneof`_ ``_province_name``.
        street_address (str):
            Street address line 1.

            This field is a member of `oneof`_ ``_street_address``.
        street_address2 (str):
            Street address line 2. This field is write-only. It is only
            used for calculating the longitude and latitude of an
            address when geo_point is empty.

            This field is a member of `oneof`_ ``_street_address2``.
        city_name (str):
            Name of the city.

            This field is a member of `oneof`_ ``_city_name``.
    """

    postal_code: str = proto.Field(
        proto.STRING,
        number=8,
        optional=True,
    )
    province_code: str = proto.Field(
        proto.STRING,
        number=9,
        optional=True,
    )
    country_code: str = proto.Field(
        proto.STRING,
        number=10,
        optional=True,
    )
    province_name: str = proto.Field(
        proto.STRING,
        number=11,
        optional=True,
    )
    street_address: str = proto.Field(
        proto.STRING,
        number=12,
        optional=True,
    )
    street_address2: str = proto.Field(
        proto.STRING,
        number=13,
        optional=True,
    )
    city_name: str = proto.Field(
        proto.STRING,
        number=14,
        optional=True,
    )


class TopicInfo(proto.Message):
    r"""A topic criterion. Use topics to target or exclude placements
    in the Google Display Network based on the category into which
    the placement falls (for example, "Pets & Animals/Pets/Dogs").


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        topic_constant (str):
            The Topic Constant resource name.

            This field is a member of `oneof`_ ``_topic_constant``.
        path (MutableSequence[str]):
            The category to target or exclude. Each
            subsequent element in the array describes a more
            specific sub-category. For example, "Pets &
            Animals", "Pets", "Dogs" represents the "Pets &
            Animals/Pets/Dogs" category.
    """

    topic_constant: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    path: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )


class LanguageInfo(proto.Message):
    r"""A language criterion.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        language_constant (str):
            The language constant resource name.

            This field is a member of `oneof`_ ``_language_constant``.
    """

    language_constant: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class IpBlockInfo(proto.Message):
    r"""An IpBlock criterion used for IP exclusions. We allow:

    - IPv4 and IPv6 addresses
     - individual addresses (192.168.0.1)
     - masks for individual addresses (192.168.0.1/32)
     - masks for Class C networks (192.168.0.1/24)


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        ip_address (str):
            The IP address of this IP block.

            This field is a member of `oneof`_ ``_ip_address``.
    """

    ip_address: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class ContentLabelInfo(proto.Message):
    r"""Content Label for category exclusion.

    Attributes:
        type_ (google.ads.googleads.v19.enums.types.ContentLabelTypeEnum.ContentLabelType):
            Content label type, required for CREATE
            operations.
    """

    type_: content_label_type.ContentLabelTypeEnum.ContentLabelType = (
        proto.Field(
            proto.ENUM,
            number=1,
            enum=content_label_type.ContentLabelTypeEnum.ContentLabelType,
        )
    )


class CarrierInfo(proto.Message):
    r"""Represents a Carrier Criterion.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        carrier_constant (str):
            The Carrier constant resource name.

            This field is a member of `oneof`_ ``_carrier_constant``.
    """

    carrier_constant: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class UserInterestInfo(proto.Message):
    r"""Represents a particular interest-based topic to be targeted.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        user_interest_category (str):
            The UserInterest resource name.

            This field is a member of `oneof`_ ``_user_interest_category``.
    """

    user_interest_category: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class WebpageInfo(proto.Message):
    r"""Represents a criterion for targeting webpages of an
    advertiser's website.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        criterion_name (str):
            The name of the criterion that is defined by
            this parameter. The name value will be used for
            identifying, sorting and filtering criteria with
            this type of parameters.

            This field is required for CREATE operations and
            is prohibited on UPDATE operations.

            This field is a member of `oneof`_ ``_criterion_name``.
        conditions (MutableSequence[google.ads.googleads.v19.common.types.WebpageConditionInfo]):
            Conditions, or logical expressions, for
            webpage targeting. The list of webpage targeting
            conditions are and-ed together when evaluated
            for targeting. An empty list of conditions
            indicates all pages of the campaign's website
            are targeted.

            This field is required for CREATE operations and
            is prohibited on UPDATE operations.
        coverage_percentage (float):
            Website criteria coverage percentage. This is
            the computed percentage of website coverage
            based on the website target, negative website
            target and negative keywords in the ad group and
            campaign. For instance, when coverage returns as
            1, it indicates it has 100% coverage. This field
            is read-only.
        sample (google.ads.googleads.v19.common.types.WebpageSampleInfo):
            List of sample urls that match the website
            target. This field is read-only.
    """

    criterion_name: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    conditions: MutableSequence["WebpageConditionInfo"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="WebpageConditionInfo",
    )
    coverage_percentage: float = proto.Field(
        proto.DOUBLE,
        number=4,
    )
    sample: "WebpageSampleInfo" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="WebpageSampleInfo",
    )


class WebpageConditionInfo(proto.Message):
    r"""Logical expression for targeting webpages of an advertiser's
    website.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        operand (google.ads.googleads.v19.enums.types.WebpageConditionOperandEnum.WebpageConditionOperand):
            Operand of webpage targeting condition.
        operator (google.ads.googleads.v19.enums.types.WebpageConditionOperatorEnum.WebpageConditionOperator):
            Operator of webpage targeting condition.
        argument (str):
            Argument of webpage targeting condition.

            This field is a member of `oneof`_ ``_argument``.
    """

    operand: (
        webpage_condition_operand.WebpageConditionOperandEnum.WebpageConditionOperand
    ) = proto.Field(
        proto.ENUM,
        number=1,
        enum=webpage_condition_operand.WebpageConditionOperandEnum.WebpageConditionOperand,
    )
    operator: (
        webpage_condition_operator.WebpageConditionOperatorEnum.WebpageConditionOperator
    ) = proto.Field(
        proto.ENUM,
        number=2,
        enum=webpage_condition_operator.WebpageConditionOperatorEnum.WebpageConditionOperator,
    )
    argument: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )


class WebpageSampleInfo(proto.Message):
    r"""List of sample urls that match the website target

    Attributes:
        sample_urls (MutableSequence[str]):
            Webpage sample urls
    """

    sample_urls: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=1,
    )


class OperatingSystemVersionInfo(proto.Message):
    r"""Represents an operating system version to be targeted.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        operating_system_version_constant (str):
            The operating system version constant
            resource name.

            This field is a member of `oneof`_ ``_operating_system_version_constant``.
    """

    operating_system_version_constant: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class AppPaymentModelInfo(proto.Message):
    r"""An app payment model criterion.

    Attributes:
        type_ (google.ads.googleads.v19.enums.types.AppPaymentModelTypeEnum.AppPaymentModelType):
            Type of the app payment model.
    """

    type_: (
        app_payment_model_type.AppPaymentModelTypeEnum.AppPaymentModelType
    ) = proto.Field(
        proto.ENUM,
        number=1,
        enum=app_payment_model_type.AppPaymentModelTypeEnum.AppPaymentModelType,
    )


class MobileDeviceInfo(proto.Message):
    r"""A mobile device criterion.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        mobile_device_constant (str):
            The mobile device constant resource name.

            This field is a member of `oneof`_ ``_mobile_device_constant``.
    """

    mobile_device_constant: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class CustomAffinityInfo(proto.Message):
    r"""A custom affinity criterion.
    A criterion of this type is only targetable.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        custom_affinity (str):
            The CustomInterest resource name.

            This field is a member of `oneof`_ ``_custom_affinity``.
    """

    custom_affinity: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class CustomIntentInfo(proto.Message):
    r"""A custom intent criterion.
    A criterion of this type is only targetable.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        custom_intent (str):
            The CustomInterest resource name.

            This field is a member of `oneof`_ ``_custom_intent``.
    """

    custom_intent: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )


class LocationGroupInfo(proto.Message):
    r"""A radius around a list of locations specified through a feed
    or assetSet.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        geo_target_constants (MutableSequence[str]):
            Geo target constant(s) restricting the scope
            of the geographic area within the feed.
            Currently only one geo target constant is
            allowed. Cannot be set with AssetSet fields.
        radius (int):
            Distance in units specifying the radius
            around targeted locations. This is required and
            must be set in CREATE operations.

            This field is a member of `oneof`_ ``_radius``.
        radius_units (google.ads.googleads.v19.enums.types.LocationGroupRadiusUnitsEnum.LocationGroupRadiusUnits):
            Unit of the radius. Miles and meters are
            supported for geo target constants. Milli miles
            and meters are supported for feed item sets and
            asset sets. This is required and must be set in
            CREATE operations.
        feed_item_sets (MutableSequence[str]):
            FeedItemSets whose FeedItems are targeted. If multiple IDs
            are specified, then all items that appear in at least one
            set are targeted. This field cannot be used with
            geo_target_constants. This is optional and can only be set
            in CREATE operations. Cannot be set with AssetSet fields.
        enable_customer_level_location_asset_set (bool):
            Denotes that the latest customer level asset set is used for
            targeting. Used with radius and radius_units. Cannot be used
            with feed, geo target constants or feed item sets. When
            using asset sets, either this field or
            location_group_asset_sets should be specified. Both cannot
            be used at the same time. This can only be set in CREATE
            operations.

            This field is a member of `oneof`_ ``_enable_customer_level_location_asset_set``.
        location_group_asset_sets (MutableSequence[str]):
            AssetSets whose Assets are targeted. If multiple IDs are
            specified, then all items that appear in at least one set
            are targeted. This field cannot be used with feed, geo
            target constants or feed item sets. When using asset sets,
            either this field or
            enable_customer_level_location_asset_set should be
            specified. Both cannot be used at the same time. This can
            only be set in CREATE operations.
    """

    geo_target_constants: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=6,
    )
    radius: int = proto.Field(
        proto.INT64,
        number=7,
        optional=True,
    )
    radius_units: (
        location_group_radius_units.LocationGroupRadiusUnitsEnum.LocationGroupRadiusUnits
    ) = proto.Field(
        proto.ENUM,
        number=4,
        enum=location_group_radius_units.LocationGroupRadiusUnitsEnum.LocationGroupRadiusUnits,
    )
    feed_item_sets: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=8,
    )
    enable_customer_level_location_asset_set: bool = proto.Field(
        proto.BOOL,
        number=9,
        optional=True,
    )
    location_group_asset_sets: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=10,
    )


class CustomAudienceInfo(proto.Message):
    r"""A custom audience criterion.

    Attributes:
        custom_audience (str):
            The CustomAudience resource name.
    """

    custom_audience: str = proto.Field(
        proto.STRING,
        number=1,
    )


class CombinedAudienceInfo(proto.Message):
    r"""A combined audience criterion.

    Attributes:
        combined_audience (str):
            The CombinedAudience resource name.
    """

    combined_audience: str = proto.Field(
        proto.STRING,
        number=1,
    )


class AudienceInfo(proto.Message):
    r"""An audience criterion.

    Attributes:
        audience (str):
            The Audience resource name.
    """

    audience: str = proto.Field(
        proto.STRING,
        number=1,
    )


class KeywordThemeInfo(proto.Message):
    r"""A Smart Campaign keyword theme.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        keyword_theme_constant (str):
            The resource name of a Smart Campaign keyword theme
            constant.
            ``keywordThemeConstants/{keyword_theme_id}~{sub_keyword_theme_id}``

            This field is a member of `oneof`_ ``keyword_theme``.
        free_form_keyword_theme (str):
            Free-form text to be matched to a Smart
            Campaign keyword theme constant on a best-effort
            basis.

            This field is a member of `oneof`_ ``keyword_theme``.
    """

    keyword_theme_constant: str = proto.Field(
        proto.STRING,
        number=1,
        oneof="keyword_theme",
    )
    free_form_keyword_theme: str = proto.Field(
        proto.STRING,
        number=2,
        oneof="keyword_theme",
    )


class LocalServiceIdInfo(proto.Message):
    r"""A Local Services Ads service ID. Represents a service type (such as
    install_faucet) that a Local Services Campaign can target.

    Attributes:
        service_id (str):
            The criterion resource name.
    """

    service_id: str = proto.Field(
        proto.STRING,
        number=1,
    )


class SearchThemeInfo(proto.Message):
    r"""A Search Theme criterion only on Performance Max campaign.
    Represents a keyword-like advertiser input.

    Attributes:
        text (str):
            Each Search Theme has a value of a simple
            string, like keywords. There are limits on
            overall length, allowed characters, and number
            of words.
    """

    text: str = proto.Field(
        proto.STRING,
        number=1,
    )


class BrandInfo(proto.Message):
    r"""Represents a Brand Criterion used for targeting based on
    commercial knowledge graph.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        display_name (str):
            Output only. A text representation of a
            brand.

            This field is a member of `oneof`_ ``_display_name``.
        entity_id (str):
            The Commercial KG MID for the brand.

            This field is a member of `oneof`_ ``_entity_id``.
        primary_url (str):
            Output only. The primary url of a brand.

            This field is a member of `oneof`_ ``_primary_url``.
        rejection_reason (google.ads.googleads.v19.enums.types.BrandRequestRejectionReasonEnum.BrandRequestRejectionReason):
            Output only. The rejection reason when a
            brand status is REJECTED.

            This field is a member of `oneof`_ ``_rejection_reason``.
        status (google.ads.googleads.v19.enums.types.BrandStateEnum.BrandState):
            Output only. The status of a brand.

            This field is a member of `oneof`_ ``_status``.
    """

    display_name: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )
    entity_id: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )
    primary_url: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    rejection_reason: (
        brand_request_rejection_reason.BrandRequestRejectionReasonEnum.BrandRequestRejectionReason
    ) = proto.Field(
        proto.ENUM,
        number=4,
        optional=True,
        enum=brand_request_rejection_reason.BrandRequestRejectionReasonEnum.BrandRequestRejectionReason,
    )
    status: brand_state.BrandStateEnum.BrandState = proto.Field(
        proto.ENUM,
        number=5,
        optional=True,
        enum=brand_state.BrandStateEnum.BrandState,
    )


class BrandListInfo(proto.Message):
    r"""A Brand List Criterion is used to specify a list of brands. The list
    is represented as a SharedSet id type BRAND_HINT. A criterion of
    this type can be either targeted or excluded.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        shared_set (str):
            Shared set resource name of the brand list.

            This field is a member of `oneof`_ ``_shared_set``.
    """

    shared_set: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore

from google.ads.googleads.v22.enums.types import geo_targeting_type


__protobuf__ = proto.module(
    package="google.ads.googleads.v22.resources",
    marshal="google.ads.googleads.v22",
    manifest={
        "GeographicView",
    },
)


class GeographicView(proto.Message):
    r"""A geographic view.

    Geographic View includes all metrics aggregated at the country
    level, one row per country. It reports metrics at either actual
    physical location of the user or an area of interest. If other
    segment fields are used, you may get more than one row per
    country.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        resource_name (str):
            Output only. The resource name of the geographic view.
            Geographic view resource names have the form:

            ``customers/{customer_id}/geographicViews/{country_criterion_id}~{location_type}``
        location_type (google.ads.googleads.v22.enums.types.GeoTargetingTypeEnum.GeoTargetingType):
            Output only. Type of the geo targeting of the
            campaign.
        country_criterion_id (int):
            Output only. Criterion Id for the country.

            This field is a member of `oneof`_ ``_country_criterion_id``.
    """

    resource_name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    location_type: geo_targeting_type.GeoTargetingTypeEnum.GeoTargetingType = (
        proto.Field(
            proto.ENUM,
            number=3,
            enum=geo_targeting_type.GeoTargetingTypeEnum.GeoTargetingType,
        )
    )
    country_criterion_id: int = proto.Field(
        proto.INT64,
        number=5,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v21.enums",
    marshal="google.ads.googleads.v21",
    manifest={
        "BiddingStrategyTypeEnum",
    },
)


class BiddingStrategyTypeEnum(proto.Message):
    r"""Container for enum describing possible bidding strategy
    types.

    """

    class BiddingStrategyType(proto.Enum):
        r"""Enum describing possible bidding strategy types.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                Used for return value only. Represents value
                unknown in this version.
            COMMISSION (16):
                Commission is an automatic bidding strategy
                in which the advertiser pays a certain portion
                of the conversion value.
            ENHANCED_CPC (2):
                Enhanced CPC is a bidding strategy that
                raises bids for clicks that seem more likely to
                lead to a conversion and lowers them for clicks
                where they seem less likely.
            FIXED_CPM (19):
                Fixed CPM is a manual bidding strategy with a
                fixed CPM.
            INVALID (17):
                Used for return value only. Indicates that a
                campaign does not have a bidding strategy. This
                prevents the campaign from serving. For example,
                a campaign may be attached to a manager bidding
                strategy and the serving account is subsequently
                unlinked from the manager account. In this case
                the campaign will automatically be detached from
                the now inaccessible manager bidding strategy
                and transition to the INVALID bidding strategy
                type.
            MANUAL_CPA (18):
                Manual bidding strategy that allows
                advertiser to set the bid per
                advertiser-specified action.
            MANUAL_CPC (3):
                Manual click based bidding where user pays
                per click.
            MANUAL_CPM (4):
                Manual impression based bidding
                where user pays per thousand impressions.
            MANUAL_CPV (13):
                A bidding strategy that pays a configurable
                amount per video view.
            MAXIMIZE_CONVERSIONS (10):
                A bidding strategy that automatically
                maximizes number of conversions given a daily
                budget.
            MAXIMIZE_CONVERSION_VALUE (11):
                An automated bidding strategy that
                automatically sets bids to maximize revenue
                while spending your budget.
            PAGE_ONE_PROMOTED (5):
                Page-One Promoted bidding scheme, which sets
                max cpc bids to target impressions on page one
                or page one promoted slots on google.com. This
                enum value is deprecated.
            PERCENT_CPC (12):
                Percent Cpc is bidding strategy where bids
                are a fraction of the advertised price for some
                good or service.
            TARGET_CPA (6):
                Target CPA is an automated bid strategy that
                sets bids to help get as many conversions as
                possible at the target cost-per-acquisition
                (CPA) you set.
            TARGET_CPM (14):
                Target CPM is an automated bid strategy that
                sets bids to help get as many impressions as
                possible at the target cost per one thousand
                impressions (CPM) you set.
            TARGET_CPV (20):
                Target CPV is an automated bidding strategy
                that sets bids to optimize performance given the
                average target cost per view.
            TARGET_IMPRESSION_SHARE (15):
                An automated bidding strategy that sets bids
                so that a certain percentage of search ads are
                shown at the top of the first page (or other
                targeted location).
            TARGET_OUTRANK_SHARE (7):
                Target Outrank Share is an automated bidding
                strategy that sets bids based on the target
                fraction of auctions where the advertiser should
                outrank a specific competitor.
                This enum value is deprecated.
            TARGET_ROAS (8):
                Target ROAS is an automated bidding strategy
                that helps you maximize revenue while averaging
                a specific target Return On Average Spend
                (ROAS).
            TARGET_SPEND (9):
                Target Spend is an automated bid strategy
                that sets your bids to help get as many clicks
                as possible within your budget.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        COMMISSION = 16
        ENHANCED_CPC = 2
        FIXED_CPM = 19
        INVALID = 17
        MANUAL_CPA = 18
        MANUAL_CPC = 3
        MANUAL_CPM = 4
        MANUAL_CPV = 13
        MAXIMIZE_CONVERSIONS = 10
        MAXIMIZE_CONVERSION_VALUE = 11
        PAGE_ONE_PROMOTED = 5
        PERCENT_CPC = 12
        TARGET_CPA = 6
        TARGET_CPM = 14
        TARGET_CPV = 20
        TARGET_IMPRESSION_SHARE = 15
        TARGET_OUTRANK_SHARE = 7
        TARGET_ROAS = 8
        TARGET_SPEND = 9


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations


import proto  # type: ignore


__protobuf__ = proto.module(
    package="google.ads.googleads.v20.enums",
    marshal="google.ads.googleads.v20",
    manifest={
        "DataLinkStatusEnum",
    },
)


class DataLinkStatusEnum(proto.Message):
    r"""Container for enum describing different types of data links."""

    class DataLinkStatus(proto.Enum):
        r"""Describes the possible data link statuses.

        Values:
            UNSPECIFIED (0):
                Not specified.
            UNKNOWN (1):
                The value is unknown in this version.
            REQUESTED (2):
                Link has been requested by one party, but not
                confirmed by the other party.
            PENDING_APPROVAL (3):
                Link is waiting for the customer to approve.
            ENABLED (4):
                Link is established and can be used as
                needed.
            DISABLED (5):
                Link is no longer valid and should be
                ignored.
            REVOKED (6):
                Link request has been cancelled by the
                requester and further cleanup may be needed.
            REJECTED (7):
                Link request has been rejected by the
                approver.
        """

        UNSPECIFIED = 0
        UNKNOWN = 1
        REQUESTED = 2
        PENDING_APPROVAL = 3
        ENABLED = 4
        DISABLED = 5
        REVOKED = 6
        REJECTED = 7


__all__ = tuple(sorted(__protobuf__.manifest))
